@@ -1,6 +1,9 @@
 package HTTP::MobileAgent::DoCoMo;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = 0.03;
+
 use base qw(HTTP::MobileAgent);
 
 __PACKAGE__->make_accessors(
@@ -8,6 +11,8 @@ __PACKAGE__->make_accessors(
        serial_number is_foma card_id comment)
 );
 
+use HTTP::MobileAgent::DoCoMoDisplayMap qw($DisplayMap);
+
 # various preferences
 use vars qw($DefaultCacheSize $HTMLVerMap $FOMAHTMLVersion);
 $DefaultCacheSize = 5;
@@ -115,6 +120,12 @@ sub vendor {
     return $1;
 }
 
+sub _make_display {
+    my $self = shift;
+    my $display = $DisplayMap->{$self->model};
+    return HTTP::MobileAgent::Display->new(%$display);
+}
+
 1;
 __END__
 
@@ -238,19 +249,6 @@ returns undef otherwise.
 
 =back
 
-=head1 TODO
-
-=over 4
-
-=item *
-
-Region and screen size support availabe at
-http://www.nttdocomo.co.jp/p_s/imode/spec/ryouiki.html
-
-(Patches are always welcome ;))
-
-=back
-
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
