@@ -1,6 +1,9 @@
 package HTTP::MobileAgent::JPhone;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = 0.03;
+
 use base qw(HTTP::MobileAgent);
 
 __PACKAGE__->make_accessors(
@@ -33,6 +36,23 @@ sub parse {
     }
 }
 
+sub _make_display {
+    my $self = shift;
+    my($width, $height) = split /\*/, $self->get_header('x-jphone-display');
+
+    my($color, $depth);
+    if (my $c_str = $self->get_header('x-jphone-color')) {
+	($color, $depth) = $c_str =~ /^([CG])(\d+)$/;
+    }
+
+    return HTTP::MobileAgent::Display->new(
+	width  => $width,
+	height => $height,
+	color  => $color eq 'C',
+	depth  => $depth,
+    );
+}
+
 1;
 __END__
 
@@ -130,10 +150,6 @@ returns undef if unknown.
 
 =item *
 
-Parse C<x-jphone-*> headers.
-
-=item *
-
 Area information support on http://www.dp.j-phone.com/jsky/position.html
 
 =back
